@@ -13,10 +13,10 @@ been stabilized.
 
 # Usage
 
-For most cases, importing the prelude should suffice.
+For most cases, importing the shims should suffice.
 
 ```rust,no_run
-use standback::prelude::*;
+use standback::shim::*;
 ```
 
 If you are using anything that would normally have to be imported, just use the `standback` crate
@@ -48,11 +48,87 @@ of a compiler are supported.
 
 Note that items stabilized prior to the declared MSRV _will not_ be re-exported.
 
-# Inherent and trait methods, associated constants
+# Inherent items
 
 The following methods and constants are available via the prelude. For brevity, `i*` is `i8`, `i16`,
 `i32`, `i64`, `i128`, and `isize`; `u*` is `u8`, `u16`, `u32`, `u64`, `u128`, and `usize`.
 
+## 1.58
+
+```text
+Metadata::is_symlink
+Path::is_symlink
+{i*, u*}::saturating_div
+Option::unwrap_unchecked
+Result::unwrap_unchecked
+Result::unwrap_err_unchecked
+NonZeroU*::is_power_of_two
+```
+
+## 1.57
+
+```text
+Iterator::map_while
+```
+
+## 1.56
+
+None :(
+
+## 1.55
+
+```text
+prelude::rust_2015
+prelude::rust_2018
+prelude::rust_2021
+Bounded::cloned
+MaybeUninit::assume_init_mut
+MaybeUninit::assume_init_ref
+MaybeUninit::write
+```
+
+## 1.54
+
+```text
+BTreeMap::into_keys
+BTreeMap::into_values
+HashMap::into_keys
+HashMap::into_values
+VecDeque::binary_search
+VecDeque::binary_search_by
+VecDeque::binary_search_by_key
+VecDeque::partition_point
+```
+
+## 1.53
+
+```text
+Ordering::is_eq
+Duration::ZERO
+Duration::is_zero
+Duration::saturating_add
+Duration::saturating_mul
+Duration::saturating_sub
+Option::insert
+Ordering::is_eq
+Ordering::is_ge
+Ordering::is_gt
+Ordering::is_le
+Ordering::is_lt
+Ordering::is_ne
+OsStr::make_ascii_lowercase
+OsStr::make_ascii_uppercase
+OsStr::to_ascii_lowercase
+OsStr::to_ascii_uppercase
+OsStr::is_ascii
+OsStr::eq_ignore_ascii_case
+Rc::decrement_strong_count
+Rc::increment_strong_count
+Vec::extend_from_within
+{f32, f64}::is_subnormal
+{i*, u*}::BITS
+```
+
 ## 1.52
 
 ```text
@@ -82,7 +158,6 @@ slice::split_inclusive
 slice::strip_prefix
 slice::strip_suffix
 str::split_inclusive
-task::Wake
 i*::unsigned_abs
 Poll::map_ok
 Poll::map_err
@@ -249,11 +324,19 @@ Option::xor
 slice::copy_within
 ```
 
-# Free functions and constants
+# Free items
 
 ```text
+array::from_ref // 1.53
+array::from_mut // 1.53
+cmp::min_by // 1.53
+cmp::max_by // 1.53
+cmp::min_by_key // 1.53
+cmp::max_by_key // 1.53
+task::Wake // 1.51
 future::pending // 1.48
 future::ready // 1.48
+{f32, f64}::consts::TAU // 1.47
 char::UNICODE_VERSION // 1.45
 {f32, f64}::consts::LOG10_2 // 1.43
 {f32, f64}::consts::LOG2_10 // 1.43
@@ -261,7 +344,7 @@ iter::once_with // 1.43
 mem::take // 1.40
 ```
 
-# Macros
+# Prelude macros (located in `standback::shim`)
 
 ```text
 matches! // 1.42
@@ -273,143 +356,60 @@ todo! // 1.39
 #[cfg(feature = "alloc")]
 extern crate alloc;
 
-mod traits {
-    pub trait Sealed<T: ?Sized> {}
-    impl<T: ?Sized> Sealed<T> for T {}
-
-    macro_rules! impl_trait_for_all {
-        ($trait:ident => $($type:ty)+) => {$(
-            impl $trait for $type {}
-        )+};
-    }
-
-    #[allow(unreachable_pub)]
-    pub trait Integer: Sized {}
-    impl_trait_for_all!(Integer => i8 i16 i32 i64 i128 isize u8 u16 u32 u64 u128 usize);
-
-    #[allow(unreachable_pub)]
-    pub trait SignedInteger {}
-    impl_trait_for_all!(SignedInteger => i8 i16 i32 i64 i128 isize);
-
-    #[allow(unreachable_pub)]
-    pub trait UnsignedInteger {}
-    impl_trait_for_all!(UnsignedInteger => u8 u16 u32 u64 u128 usize);
-
-    #[allow(unreachable_pub)]
-    pub trait Float {}
-    impl_trait_for_all!(Float => f32 f64);
-}
-
+mod inherent;
 mod pattern;
 
-#[cfg(shim = "1.37")]
-mod v1_37;
-#[cfg(shim = "1.38")]
-mod v1_38;
-#[cfg(shim = "1.40")]
-mod v1_40;
-#[cfg(shim = "1.41")]
-mod v1_41;
-#[cfg(shim = "1.42")]
-mod v1_42;
-#[cfg(shim = "1.43")]
-mod v1_43;
-#[cfg(shim = "1.44")]
-mod v1_44;
-#[cfg(shim = "1.45")]
-mod v1_45;
-#[cfg(shim = "1.46")]
-mod v1_46;
-#[cfg(shim = "1.47")]
-mod v1_47;
-#[cfg(shim = "1.48")]
-mod v1_48;
-#[cfg(shim = "1.49")]
-mod v1_49;
-#[cfg(shim = "1.50")]
-mod v1_50;
-#[cfg(shim = "1.51")]
-mod v1_51;
-#[cfg(shim = "1.52")]
-mod v1_52;
+mod free {
+    #[cfg(shim = "1.40")] pub(crate) mod v1_40;
+    #[cfg(shim = "1.43")] pub(crate) mod v1_43;
+    #[cfg(shim = "1.47")] pub(crate) mod v1_47;
+    #[cfg(shim = "1.48")] pub(crate) mod v1_48;
+    #[cfg(shim = "1.51")] pub(crate) mod v1_51;
+    #[cfg(shim = "1.53")] pub(crate) mod v1_53;
+}
 
 #[doc(hidden)]
-pub mod prelude {
+pub mod shim {
     #[cfg(shim = "1.39")]
     pub use core::unimplemented as todo;
 
-    #[cfg(shim = "1.42")]
-    pub use crate::matches;
-    #[cfg(shim = "1.37")]
-    pub use crate::v1_37::{
-        Cell_v1_37, Cell_v1_37_, DoubleEndedIterator_v1_37, Option_v1_37, Slice_v1_37,
-    };
-    #[cfg(all(shim = "1.38", feature = "std"))]
-    pub use crate::v1_38::EuclidFloat_v1_38;
-    #[cfg(shim = "1.38")]
-    pub use crate::v1_38::{ConstPtr_v1_38, Duration_v1_38, Euclid_v1_38, MutPtr_v1_38};
-    #[cfg(all(shim = "1.40", feature = "alloc"))]
-    pub use crate::v1_40::slice_v1_40;
-    #[cfg(shim = "1.40")]
-    pub use crate::v1_40::{f32_v1_40, f64_v1_40, Option_v1_40, Option_v1_40_};
-    #[cfg(shim = "1.41")]
-    pub use crate::v1_41::Result_v1_41;
-    #[cfg(all(shim = "1.42", feature = "std"))]
-    pub use crate::v1_42::Condvar_v1_42;
-    #[cfg(shim = "1.42")]
-    pub use crate::v1_42::ManuallyDrop_v1_42;
-    #[cfg(shim = "1.43")]
-    pub use crate::v1_43::{float_v1_43, int_v1_43};
-    #[cfg(all(shim = "1.44", feature = "std"))]
-    pub use crate::v1_44::PathBuf_v1_44;
-    #[cfg(shim = "1.44")]
-    pub use crate::v1_44::{float_v1_44, Layout_v1_44};
-    #[cfg(shim = "1.45")]
-    pub use crate::v1_45::{int_v1_45, str_v1_45};
-    #[cfg(shim = "1.46")]
-    pub use crate::v1_46::{int_v1_46, Option_v1_46};
-    #[cfg(all(shim = "1.47", feature = "alloc"))]
-    pub use crate::v1_47::Vec_v1_47;
-    #[cfg(shim = "1.47")]
-    pub use crate::v1_47::{Range_v1_47, Result_v1_47};
-    #[cfg(shim = "1.48")]
-    pub use crate::v1_48::Slice_v1_48;
-    #[cfg(shim = "1.49")]
-    pub use crate::v1_49::Slice_v1_49;
-    #[cfg(all(shim = "1.50", feature = "alloc"))]
-    pub use crate::v1_50::BTreeMapEntry_v1_50;
-    #[cfg(all(shim = "1.50", feature = "std"))]
-    pub use crate::v1_50::HashMapEntry_v1_50;
-    #[cfg(shim = "1.50")]
-    pub use crate::v1_50::{
-        Bool_v1_50, Float_v1_50, Ord_v1_50, RefCell_v1_50, Slice_v1_50, UnsafeCell_v1_50,
-    };
-    #[cfg(all(shim = "1.51", feature = "alloc"))]
-    pub use crate::v1_51::Arc_v1_51;
-    #[cfg(all(shim = "1.51", feature = "std"))]
-    pub use crate::v1_51::Seek_v1_51;
-    #[cfg(shim = "1.51")]
-    pub use crate::v1_51::{
-        str_v1_51, Peekable_v1_51, Poll_v1_51, SignedInteger_v1_51, Slice_v1_51,
-    };
-    #[cfg(shim = "1.52")]
-    pub use crate::v1_52::{char_v1_52, str_v1_52, Slice_v1_52};
+    pub use crate::inherent::*;
+    #[cfg(shim = "1.42")] pub use crate::matches;
+}
+#[doc(hidden)]
+pub mod prelude {
+    #[cfg(not(feature = "std"))]
+    pub use core::prelude::v1 as rust_2015;
+    #[cfg(feature = "std")]
+    pub use std::prelude::v1 as rust_2015;
+
+    pub use rust_2015 as rust_2018;
+
+    pub mod rust_2021 {
+        pub use core::convert::{TryFrom, TryInto};
+        pub use core::iter::FromIterator;
+
+        pub use crate::prelude::rust_2015::*;
+    }
 }
 #[doc(hidden)]
 pub mod mem {
-    #[cfg(reexport = "1.40")]
-    pub use core::mem::take;
+    #[cfg(reexport = "1.40")] pub use core::mem::take;
 
     #[cfg(shim = "1.40")]
-    pub use crate::v1_40::take;
+    pub use crate::free::v1_40::mem::*;
 }
 #[doc(hidden)]
 pub mod iter {
+    #[cfg(reexport = "1.57")]
+    pub use core::iter::MapWhile;
     #[cfg(reexport = "1.43")]
     pub use core::iter::{once_with, OnceWith};
 
     #[cfg(shim = "1.43")]
-    pub use crate::v1_43::{once_with, OnceWith};
+    pub use crate::free::v1_43::iter::*;
+    #[cfg(shim = "1.57")]
+    pub use crate::inherent::MapWhile;
 }
 #[doc(hidden)]
 pub mod task {
@@ -417,7 +417,7 @@ pub mod task {
     pub use alloc::task::Wake;
 
     #[cfg(all(shim = "1.51", feature = "alloc"))]
-    pub use crate::v1_51::Wake;
+    pub use crate::free::v1_51::task::*;
 }
 #[doc(hidden)]
 pub mod f32 {
@@ -428,9 +428,9 @@ pub mod f32 {
         pub use core::f32::consts::{LOG10_2, LOG2_10};
 
         #[cfg(shim = "1.43")]
-        pub use crate::v1_43::f32::{LOG10_2, LOG2_10};
+        pub use crate::free::v1_43::f32::consts::*;
         #[cfg(shim = "1.47")]
-        pub use crate::v1_47::f32::TAU;
+        pub use crate::free::v1_47::f32::consts::*;
     }
 }
 #[doc(hidden)]
@@ -442,9 +442,9 @@ pub mod f64 {
         pub use core::f64::consts::{LOG10_2, LOG2_10};
 
         #[cfg(shim = "1.43")]
-        pub use crate::v1_43::f64::{LOG10_2, LOG2_10};
+        pub use crate::free::v1_43::f64::consts::*;
         #[cfg(shim = "1.47")]
-        pub use crate::v1_47::f64::TAU;
+        pub use crate::free::v1_47::f64::consts::*;
     }
 }
 #[doc(hidden)]
@@ -464,5 +464,21 @@ pub mod future {
     pub use core::future::{pending, ready, Pending, Ready};
 
     #[cfg(shim = "1.48")]
-    pub use crate::v1_48::future::{pending, ready, Pending, Ready};
+    pub use crate::free::v1_48::future::*;
+}
+#[doc(hidden)]
+pub mod array {
+    #[cfg(reexport = "1.53")]
+    pub use core::array::{from_mut, from_ref};
+
+    #[cfg(shim = "1.53")]
+    pub use crate::free::v1_53::array::*;
+}
+#[doc(hidden)]
+pub mod cmp {
+    #[cfg(reexport = "1.53")]
+    pub use core::cmp::{max_by, max_by_key, min_by, min_by_key};
+
+    #[cfg(shim = "1.53")]
+    pub use crate::free::v1_53::cmp::*;
 }
